@@ -77,12 +77,19 @@ describe 'ironic::conductor' do
       is_expected.to contain_ironic_config('deploy/default_boot_option').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('deploy/default_boot_mode').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('neutron/port_setup_delay').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('conductor/soft_power_off_timeout').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/power_state_change_timeout').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/sync_power_state_interval').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/sync_power_state_workers').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/power_state_sync_max_retries').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/power_failure_recovery_interval').with(:value => '<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('conductor/conductor_group').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('conductor/deploy_kernel').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('conductor/deploy_ramdisk').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('conductor/rescue_kernel').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('conductor/rescue_ramdisk').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('conductor/bootloader').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('DEFAULT/image_download_concurrency').with(:value => '<SERVICE DEFAULT>')
     end
 
     context 'when overriding parameters' do
@@ -106,6 +113,7 @@ describe 'ironic::conductor' do
           :default_boot_option               => 'local',
           :default_boot_mode                 => 'uefi',
           :port_setup_delay                  => '15',
+          :soft_power_off_timeout            => 600,
           :power_state_change_timeout        => '300',
           :sync_power_state_interval         => 120,
           :sync_power_state_workers          => 2,
@@ -116,7 +124,9 @@ describe 'ironic::conductor' do
           :deploy_ramdisk                    => 'http://host/deploy.ramdisk',
           :rescue_kernel                     => 'http://host/rescue.kernel',
           :rescue_ramdisk                    => 'http://host/rescue.ramdisk',
+          :bootloader                        => 'http://host/bootloader',
           :allow_provisioning_in_maintenance => false,
+          :image_download_concurrency        => 20,
         )
       end
       it 'should replace default parameter with new value' do
@@ -139,6 +149,7 @@ describe 'ironic::conductor' do
         is_expected.to contain_ironic_config('deploy/default_boot_option').with_value(p[:default_boot_option])
         is_expected.to contain_ironic_config('deploy/default_boot_mode').with_value(p[:default_boot_mode])
         is_expected.to contain_ironic_config('neutron/port_setup_delay').with_value(p[:port_setup_delay])
+        is_expected.to contain_ironic_config('conductor/soft_power_off_timeout').with_value(p[:soft_power_off_timeout])
         is_expected.to contain_ironic_config('conductor/power_state_change_timeout').with_value(p[:power_state_change_timeout])
         is_expected.to contain_ironic_config('conductor/sync_power_state_interval').with_value(p[:sync_power_state_interval])
         is_expected.to contain_ironic_config('conductor/sync_power_state_workers').with_value(p[:sync_power_state_workers])
@@ -149,7 +160,9 @@ describe 'ironic::conductor' do
         is_expected.to contain_ironic_config('conductor/deploy_ramdisk').with_value(p[:deploy_ramdisk])
         is_expected.to contain_ironic_config('conductor/rescue_kernel').with_value(p[:rescue_kernel])
         is_expected.to contain_ironic_config('conductor/rescue_ramdisk').with_value(p[:rescue_ramdisk])
+        is_expected.to contain_ironic_config('conductor/bootloader').with_value(p[:bootloader])
         is_expected.to contain_ironic_config('conductor/allow_provisioning_in_maintenance').with_value(p[:allow_provisioning_in_maintenance])
+        is_expected.to contain_ironic_config('DEFAULT/image_download_concurrency').with_value(p[:image_download_concurrency])
       end
     end
 
