@@ -37,7 +37,10 @@ describe 'ironic::db::postgresql' do
         }))
       end
 
-      it_behaves_like 'ironic::db::postgresql'
+      # TODO(tkajinam): Remove this once puppet-postgresql supports CentOS 9
+      unless facts[:osfamily] == 'RedHat' and facts[:operatingsystemmajrelease].to_i >= 9
+        it_behaves_like 'ironic::db::postgresql'
+      end
     end
   end
 
