@@ -41,37 +41,40 @@ describe 'ironic::glance' do
       is_expected.to contain_ironic_config('glance/password').with_value('<SERVICE DEFAULT>').with_secret(true)
       is_expected.to contain_ironic_config('glance/user_domain_name').with_value('Default')
       is_expected.to contain_ironic_config('glance/project_domain_name').with_value('Default')
+      is_expected.to contain_ironic_config('glance/system_scope').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('glance/region_name').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('glance/insecure').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('glance/num_retries').with_value('<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('glance/swift_account').with(:value => '<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('glance/swift_container').with(:value => '<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('glance/swift_endpoint_url').with(:value => '<SERVICE DEFAULT>')
-      is_expected.to contain_ironic_config('glance/swift_temp_url_key').with(:value => '<SERVICE DEFAULT>').with_secret(true)
-      is_expected.to contain_ironic_config('glance/swift_temp_url_duration').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('glance/swift_account').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('glance/swift_account_prefix').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('glance/swift_container').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('glance/swift_endpoint_url').with_value('<SERVICE DEFAULT>')
+      is_expected.to contain_ironic_config('glance/swift_temp_url_key').with_value('<SERVICE DEFAULT>').with_secret(true)
+      is_expected.to contain_ironic_config('glance/swift_temp_url_duration').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_config('glance/endpoint_override').with_value('<SERVICE DEFAULT>')
     end
 
     context 'when overriding parameters' do
       before :each do
         params.merge!(
-            :auth_type               => 'noauth',
-            :auth_url                => 'http://example.com',
-            :project_name            => 'project1',
-            :username                => 'admin',
-            :password                => 'pa$$w0rd',
-            :user_domain_name        => 'NonDefault',
-            :project_domain_name     => 'NonDefault',
-            :region_name             => 'regionTwo',
-            :api_servers             => '10.0.0.1:9292',
-            :api_insecure            => true,
-            :num_retries             => 42,
-            :swift_account           => '00000000-0000-0000-0000-000000000000',
-            :swift_container         => 'glance',
-            :swift_endpoint_url      => 'http://example2.com',
-            :swift_temp_url_key      => 'the-key',
-            :swift_temp_url_duration => 3600,
-            :endpoint_override   => 'http://example2.com',
+          :auth_type               => 'noauth',
+          :auth_url                => 'http://example.com',
+          :project_name            => 'project1',
+          :username                => 'admin',
+          :password                => 'pa$$w0rd',
+          :user_domain_name        => 'NonDefault',
+          :project_domain_name     => 'NonDefault',
+          :region_name             => 'regionTwo',
+          :api_servers             => '10.0.0.1:9292',
+          :api_insecure            => true,
+          :num_retries             => 42,
+          :swift_account           => '00000000-0000-0000-0000-000000000000',
+          :swift_account_prefix    => 'AUTH',
+          :swift_container         => 'glance',
+          :swift_endpoint_url      => 'http://example2.com',
+          :swift_temp_url_key      => 'the-key',
+          :swift_temp_url_duration => 3600,
+          :endpoint_override   => 'http://example2.com',
         )
       end
 
@@ -83,10 +86,12 @@ describe 'ironic::glance' do
         is_expected.to contain_ironic_config('glance/password').with_value(p[:password]).with_secret(true)
         is_expected.to contain_ironic_config('glance/user_domain_name').with_value(p[:user_domain_name])
         is_expected.to contain_ironic_config('glance/project_domain_name').with_value(p[:project_domain_name])
+        is_expected.to contain_ironic_config('glance/system_scope').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_ironic_config('glance/region_name').with_value(p[:region_name])
         is_expected.to contain_ironic_config('glance/insecure').with_value(p[:api_insecure])
         is_expected.to contain_ironic_config('glance/num_retries').with_value(p[:num_retries])
         is_expected.to contain_ironic_config('glance/swift_account').with_value(p[:swift_account])
+        is_expected.to contain_ironic_config('glance/swift_account_prefix').with_value(p[:swift_account_prefix])
         is_expected.to contain_ironic_config('glance/swift_container').with_value(p[:swift_container])
         is_expected.to contain_ironic_config('glance/swift_endpoint_url').with_value(p[:swift_endpoint_url])
         is_expected.to contain_ironic_config('glance/swift_temp_url_key').with_value(p[:swift_temp_url_key]).with_secret(true)
@@ -106,6 +111,18 @@ describe 'ironic::glance' do
       end
     end
 
+    context 'when system_scope is set' do
+      before do
+        params.merge!(
+          :system_scope => 'all'
+        )
+      end
+      it 'configures system-scoped credential' do
+        is_expected.to contain_ironic_config('glance/project_domain_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_ironic_config('glance/project_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_ironic_config('glance/system_scope').with_value('all')
+      end
+    end
   end
 
   on_supported_os({
