@@ -34,7 +34,10 @@ describe 'ironic::inspector::db::postgresql' do
         facts.merge(OSDefaults.get_facts())
       end
 
-      it_behaves_like 'ironic::inspector::db::postgresql'
+      # TODO(tkajinam): Remove this once puppet-postgresql supports CentOS 9
+      unless facts[:osfamily] == 'RedHat' and facts[:operatingsystemmajrelease].to_i >= 9
+        it_behaves_like 'ironic::inspector::db::postgresql'
+      end
     end
   end
 
