@@ -35,16 +35,6 @@ describe 'ironic::inspector' do
       :add_ports             => 'pxe',
       :keep_ports            => 'all',
       :store_data            => 'none',
-      :ironic_auth_type      => 'password',
-      :ironic_username       => 'ironic',
-      :ironic_tenant_name    => 'services',
-      :ironic_auth_url       => 'http://127.0.0.1:5000/v3',
-      :ironic_max_retries    => 30,
-      :ironic_retry_interval => 2,
-      :swift_auth_type       => 'password',
-      :swift_username        => 'ironic',
-      :swift_tenant_name     => 'services',
-      :swift_auth_url        => 'http://127.0.0.1:5000/v3',
       :dnsmasq_ip_subnets    => [{ 'ip_range' =>
                                       '192.168.0.100,192.168.0.120',
                                    'mtu' => '1350'},
@@ -69,7 +59,8 @@ describe 'ironic::inspector' do
       :ipxe_timeout          => 0,
       :http_port             => 8088,
       :tftp_root             => '/tftpboot',
-      :http_root             => '/httpboot', }
+      :http_root             => '/httpboot',
+    }
   end
 
 
@@ -122,6 +113,7 @@ describe 'ironic::inspector' do
       is_expected.to contain_ironic_inspector_config('DEFAULT/auth_strategy').with_value(p[:auth_strategy])
       is_expected.to contain_ironic_inspector_config('DEFAULT/timeout').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_inspector_config('DEFAULT/transport_url').with_value('fake://')
+      is_expected.to contain_ironic_inspector_config('DEFAULT/api_max_limit').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_inspector_config('capabilities/boot_mode').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_inspector_config('iptables/dnsmasq_interface').with_value(p[:dnsmasq_interface])
       is_expected.to contain_ironic_inspector_config('processing/ramdisk_logs_dir').with_value(p[:ramdisk_logs_dir])
@@ -129,20 +121,6 @@ describe 'ironic::inspector' do
       is_expected.to contain_ironic_inspector_config('processing/add_ports').with_value(p[:add_ports])
       is_expected.to contain_ironic_inspector_config('processing/keep_ports').with_value(p[:keep_ports])
       is_expected.to contain_ironic_inspector_config('processing/store_data').with_value(p[:store_data])
-      is_expected.to contain_ironic_inspector_config('ironic/auth_type').with_value(p[:ironic_auth_type])
-      is_expected.to contain_ironic_inspector_config('ironic/username').with_value(p[:ironic_username])
-      is_expected.to contain_ironic_inspector_config('ironic/project_name').with_value(p[:ironic_tenant_name])
-      is_expected.to contain_ironic_inspector_config('ironic/project_domain_name').with_value('Default')
-      is_expected.to contain_ironic_inspector_config('ironic/user_domain_name').with_value('Default')
-      is_expected.to contain_ironic_inspector_config('ironic/auth_url').with_value(p[:ironic_auth_url])
-      is_expected.to contain_ironic_inspector_config('ironic/max_retries').with_value(p[:ironic_max_retries])
-      is_expected.to contain_ironic_inspector_config('ironic/retry_interval').with_value(p[:ironic_retry_interval])
-      is_expected.to contain_ironic_inspector_config('swift/auth_type').with_value(p[:swift_auth_type])
-      is_expected.to contain_ironic_inspector_config('swift/username').with_value(p[:swift_username])
-      is_expected.to contain_ironic_inspector_config('swift/project_name').with_value(p[:swift_tenant_name])
-      is_expected.to contain_ironic_inspector_config('swift/project_domain_name').with_value('Default')
-      is_expected.to contain_ironic_inspector_config('swift/user_domain_name').with_value('Default')
-      is_expected.to contain_ironic_inspector_config('swift/auth_url').with_value(p[:swift_auth_url])
       is_expected.to contain_ironic_inspector_config('processing/processing_hooks').with_value('$default_processing_hooks')
       is_expected.to contain_ironic_inspector_config('processing/node_not_found_hook').with_value('<SERVICE DEFAULT>')
       is_expected.to contain_ironic_inspector_config('discovery/enroll_node_driver').with_value('<SERVICE DEFAULT>')
@@ -196,6 +174,9 @@ describe 'ironic::inspector' do
       is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
         /dhcp-sequential-ip/
       )
+      is_expected.not_to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+        /log-facility=.*/
+      )
     end
     it 'should contain file /tftpboot/pxelinux.cfg/default' do
       is_expected.to contain_file('/tftpboot/pxelinux.cfg/default').with(
@@ -216,14 +197,7 @@ describe 'ironic::inspector' do
         params.merge!(
           :dhcp_debug                  => true,
           :listen_address              => '127.0.0.1',
-          :ironic_password             => 'password',
-          :ironic_project_domain_name  => 'Default',
-          :ironic_user_domain_name     => 'Default',
-          :ironic_auth_url             => 'http://192.168.0.1:5000/v3',
-          :swift_password              => 'password',
-          :swift_project_domain_name   => 'Default',
-          :swift_user_domain_name      => 'Default',
-          :swift_auth_url              => 'http://192.168.0.1:5000/v3',
+          :api_max_limit               => 100,
           :pxe_transfer_protocol       => 'http',
           :additional_processing_hooks => 'hook1,hook2',
           :ramdisk_kernel_args         => 'foo=bar',
@@ -235,23 +209,18 @@ describe 'ironic::inspector' do
           :discovery_default_driver    => 'pxe_ipmitool',
           :dnsmasq_ip_subnets          => [{'ip_range' => '192.168.0.100,192.168.0.120'}],
           :dnsmasq_dhcp_sequential_ip  => false,
+          :dnsmasq_log_facility        => '/var/log/ironic-inspector/dnsmasq.log',
           :add_ports                   => 'all',
           :always_store_ramdisk_logs   => true,
           :port_physnet_cidr_map       => {'192.168.20.0/24' => 'physnet_a',
                                            '2001:db8::/64' => 'physnet_b'},
+          :uefi_ipxe_bootfile_name     => 'otherpxe.efi',
         )
       end
       it 'should replace default parameter with new value' do
         is_expected.to contain_ironic_inspector_config('DEFAULT/listen_address').with_value(p[:listen_address])
+        is_expected.to contain_ironic_inspector_config('DEFAULT/api_max_limit').with_value(100)
         is_expected.to contain_ironic_inspector_config('capabilities/boot_mode').with_value(p[:detect_boot_mode])
-        is_expected.to contain_ironic_inspector_config('ironic/password').with_value(p[:ironic_password]).with_secret(true)
-        is_expected.to contain_ironic_inspector_config('ironic/project_domain_name').with_value(p[:ironic_project_domain_name])
-        is_expected.to contain_ironic_inspector_config('ironic/user_domain_name').with_value(p[:ironic_user_domain_name])
-        is_expected.to contain_ironic_inspector_config('ironic/auth_url').with_value(p[:ironic_auth_url])
-        is_expected.to contain_ironic_inspector_config('swift/password').with_value(p[:swift_password]).with_secret(true)
-        is_expected.to contain_ironic_inspector_config('swift/project_domain_name').with_value(p[:swift_project_domain_name])
-        is_expected.to contain_ironic_inspector_config('swift/user_domain_name').with_value(p[:swift_user_domain_name])
-        is_expected.to contain_ironic_inspector_config('swift/auth_url').with_value(p[:swift_auth_url])
         is_expected.to contain_ironic_inspector_config('processing/processing_hooks').with_value('$default_processing_hooks,hook1,hook2')
         is_expected.to contain_ironic_inspector_config('processing/node_not_found_hook').with_value('enroll')
         is_expected.to contain_ironic_inspector_config('processing/add_ports').with_value('all')
@@ -287,6 +256,16 @@ describe 'ironic::inspector' do
         is_expected.not_to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
             /dhcp-sequential-ip/
         )
+        is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+            /log-facility=\/var\/log\/ironic-inspector\/dnsmasq.log/
+        )
+        is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+            /dhcp-boot=tag:efi,tag:!ipxe,otherpxe.efi/
+        )
+        is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
+            /dhcp-option=tag:efi6,tag:!ipxe6,option6:bootfile-url,tftp:\/\/.*\/otherpxe.efi/
+        )
+
       end
       it 'should contain file /var/www/httpboot/inspector.ipxe' do
         is_expected.to contain_file('/var/www/httpboot/inspector.ipxe').with(
@@ -332,8 +311,7 @@ describe 'ironic::inspector' do
 
     context 'when enabling ppc64le support' do
       let :pre_condition do
-         "class { 'ironic::inspector::authtoken': password       => 'password', }
-          class { 'ironic::pxe':                  enable_ppc64le => true, }"
+         "class { 'ironic::inspector::authtoken': password       => 'password', }"
       end
 
       before do
@@ -346,6 +324,15 @@ describe 'ironic::inspector' do
           is_expected.to contain_file('/etc/ironic-inspector/dnsmasq.conf').with_content(
             /dhcp-match=set:ppc64le,option:client-arch,14/)
       end
+      it 'should contain directory /tftpboot/ppc64le with selinux type tftpdir_t' do
+        is_expected.to contain_file('/tftpboot/ppc64le').with(
+          'owner'   => 'ironic-inspector',
+          'group'   => 'ironic-inspector',
+          'require' => 'Anchor[ironic-inspector::config::begin]',
+          'ensure'  => 'directory',
+          'seltype' => 'tftpdir_t',
+        )
+      end
       it 'should contain file /tftpboot/ppc64le/default' do
         is_expected.to contain_file('/tftpboot/ppc64le/default').with(
           'owner'   => 'ironic-inspector',
@@ -363,8 +350,7 @@ describe 'ironic::inspector' do
 
     context 'when enabling ppc64le support with http default transport' do
       let :pre_condition do
-         "class { 'ironic::inspector::authtoken': password       => 'password', }
-          class { 'ironic::pxe':                  enable_ppc64le => true, }"
+         "class { 'ironic::inspector::authtoken': password       => 'password', }"
       end
 
       before do
